%% ===========================================================================
% Copyright (C) 1998,99 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% 
% Description   : Main simulation program
%
% File          : Main.m
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.B.Nordstrom@Telia.se)
%               : 
%
% CVS:       $Id: Main.m,v 1.14 1999/03/31 13:15:26 tono Exp $
%% ===========================================================================

%% ===========================================================================
% Change History
%      1998-11-12 (ToNo) Created
%      1998-11-13 (ToNo) Modified to the split of experiment setup
%      1998-12-08 (DaB)  Updated
%      1998-12-21 (ToNo) Updated to get in sync with uiMain
%      1998-01-07 (ToNo) Removed modem under test
%      1998-01-14 (ToNo) Fixed spelling of FTTEx (Thanks Gye Tae Kihl)
%      1998-01-14 (ToNo) Updated to get in sync with uiMain
%      1999-02-05 (DaB)  Changed to fit new param structure
%      1999-02-25 (ToNo) Generlized list (tfplist) handling
%      1999-03-25 (ToNo) Restructured the source (moved into subdir xdslcomm)
%% ===========================================================================

global ex;
global res;
addpath xdslcomm;

% Test if we have problem reading numbers in international OS versions
if 3 == 3.14,
    error(['Matlab thinks 3 is equal to 3.14, ' ...
            'please use an US (or posix C) version of the system. ' ...
            'Or add LC_NUMERIC=us into $MATLAB/bin/.matlab5rc.sh' ]);
end

scenario='FSAN scenario FTTEx #1';
vdslDuplex	= 'VDSL-FDD';                   % Duplex method for VDSL

% Set up the experiment structures
ex.param 	= setupParam(vdslDuplex);               % Parameters
ex.ttlist       = setupTTstructure;			% Traffic & Topology
ex.tt           = getList(ex.ttlist,scenario);
ex.tfplist 	= setupTFplan;				% Time & Freq. plans

% Test both ADSL and VDSL
ex.param.modemlist=['VDSL';'ADSL'];

% Show traffic and topology structure
figure(1);
plotTTstructure(ex.tt);

% Show PSD masks for VDSL modem
tfplan = getList(ex.tfplist,vdslDuplex);
figure(2);
fax.min=1e3; fax.max=12e6;
plotTFplan(tfplan,'Lin',fax);

drawnow; % Show it now

% Evaluate this experiment
result = evalExperiment;

% Show the result from the experiment
format compact
[bitrate_LT, bitrate_NT]=calcFSANresult(ex,result);
sprintf('LT Rates')
bitrate_LT
sprintf('NT Rates')
bitrate_NT
sprintf('Ratio')
bitrate_NT./bitrate_LT

% Plot the result from experiment
for current=1:length(result),
    figure;
    tmp_str=sprintf('FSAN Duplex Simulation Result, Modem %d',current);
    set(gcf,'NumberTitle','off','Name',tmp_str);

    % Plot the LT side
    subplot(211)
    plotResult(ex,result,current,'LT');

    % Plot the NT side
    subplot(212)
    plotResult(ex,result,current,'NT');
end
% or do uiResults(ex,result) to get the gui interface for the results
