%% ===========================================================================
% Copyright (C) 1999 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% 
% Description   : File containing user definitions for an fsan experiment
%
% File          : userDefinitionsExample1.m
% Project       : FSAN simulator
% Author(s)     : Tomas Nordstrom (Tomas.B.Nordstrom@Telia.se)
%
% CVS:       $Id: userDefinitionsExample1.m,v 1.3 1999/03/31 13:15:33 tono Exp $
%% ===========================================================================

%% ===========================================================================
% Change History
%      1998-02-26 (ToNo) Created
%% ===========================================================================
global ex;

%% ===========================================================================
% Below follows any user modifications to the experiment setups

scenario	= 'My own Scenario';		% Scenario to run
vdslDuplex	= 'VDSL-XXX';                   % Duplex method for VDSL

% Set up the experiment structures
ex.param.vdslDuplex 	= vdslDuplex;

% Add our own VDSL definition
tmp_tfplan=getList(ex.tfplist,ex.param.HambandName); % initiate tmp_tfplan
tmp_tfplan.name='VDSL-XXX';
% PSD masks
tmp_tfplan.downstream ='calcPSD([.3e6 -160 .3e6 -60 3.5e6 -60 3.5e6 -160],''Linear'')'; 
tmp_tfplan.upstream   ='calcPSD([3.5e6 -160 3.5e6 -60 10e6 -60 10e6 -160],''Linear'')'; 
tmp_tfplan.timeDivision.up=1;		% Time used in up resp. down link
tmp_tfplan.timeDivision.down=1;	
tmp_tfplan.PBOmethod='RefFreq';		% Power back-off method 
tmp_tfplan.PBOparam=2e6;		% PBO parameter {length(m) or frequency(Hz)}
tmp_tfplan.efficiencyLoss=0;		
tmp_tfplan.active.upstream=[0.3e6 10e6];
tmp_tfplan.active.downstream=[0.3e6 10e6];
ex.tfplist=insertList(ex.tfplist,tmp_tfplan);

% Change technology specifics
ex.param.SNRMax         = 60;		% Maximum SNR available (dB)
ex.param.shannonGap     = 9.8; 	        % Shannon gap (dB)
ex.param.efficiencyLoss = 0.15; 	% Efficiency loss, due to things like cyclic
				        % prefix etc.
% Use our own scenario
tt.name=scenario;
tt.topology=[
    {0  '' 'CO' ''}; 
    {500  'DTAG04' 'N1' ''}; 		% Distance, Cable, Node name, Line name
    {500  'DTAG04' 'N2' ''}; 
    {500  'DTAG04' 'N3' ''}; 
    {1500 'DTAG04' 'C'  ''}; 
    {500  'DTAG04' 'N4' ''}; 
    ];
tt.dm=[1 2 3 4];			% Distrubed modems
tt.traffic=[
    {1 2 'VDSL' 3};			% From node, to node, tfplan, no modems
    {1 2 'ADSL' 4}; 
    {1 3 'VDSL' 4}; 
    {1 4 'ISDN-2B1Q' 3};
    {1 4 'ADSL' 1}; 
    {1 5 'HDSL-1' 3};
    {5 6 'VDSL' 3};
    {5 6 'ADSL' 4}; 
    ];
ex.ttlist=insertList(ex.ttlist,tt);	% Insert into list (used for GUI)
ex.tt=tt;				% Define the experiment tt structure

% Test both ADSL and VDSL
ex.param.modemlist=['VDSL';'ADSL'];
