%% ===========================================================================
% FSAN xDSL simulation tool
%
% Main experiment routines
%  setupParam           Routine to set up the parameter part of the ex structure
%  evalExperiment       The main evaluation routine
%  uiSetup  		GUI setup window
%
% Results
%  uiResults  		GUI result window
%  plotResult  		Plot a result plot
%  calcFSANresult  	Calculate resulting bit rates
%
% Time and frequency plans for modems and disturbers
%  setupTFplan          Routine to set up the FT plan part of the ex structure
%  plotTFplan           Plots the PSD mask for a certain TF plan
%
%  calcPSD              Generates a PSD mask from a PSD description
%  modelPSD_isdn_pra    PSD mask model/function for ISDN PRA
%
% Traffic and topology structure
%  setupTTstructure     Routine to set up the TT part of the ex structure
%  plotTTstructure      Plots the TT structure
%
% List handling routines
%
%  getList		Get an object from a list based on the name of the objects
%  getNameList		Get list of names of the objects in a list
%  insertList		Insert an object into a list
%  setList		Set a named object in a list to a new value (object)

% Help functions
%  addFSAN              Adds noise according to the FSAN combination method
%  calcTheoBitLoad  	Calculate theoretical bit-loading
%  calcRate             Calculates the total rate from f_start to f_stop
%  callbackGO           Callback function for GO button in uiSetup
%  checkEx              Check experiment description in the global structure ex
%  evalNoise  		Calc noise in LT & NT nodes from disturber in start to stop node 
%  evalPBO  		Calculates power back-off (PBO) for up and downstream
%  findStrIndex         Find string (index) in array of strings
%  getCableModel        Get the parameters for a given cable
%  getDM                Finds index in traffic that matchs modem types (ADSL/VDSL)
%  getNoiseModels       Gets all available noise models for this tool
%  getMinFreqaxis  	Finds minimal set of frequencies for frequency axis
%  getMaxVDSLlength     Get the maximum VDSL modem length
%  getPBOmethods        Gets all available PBO methods for this tool
%  getScenarios  	Gets all available scenarios for this tool
%  setupPSDplan         Generate a PSD description from a simple list - not used
%  stdCables            Defines many standard cable models
%
% Misc
%  Content  		This file

%% ===========================================================================
% Copyright (C) 1998 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% 
% Description   : FSAN duplex simulation model
%
% File          : Content.m
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.B.Nordstrom@Telia.se)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: Content.m,v 1.3 1999/03/31 13:15:37 tono Exp $
%% ===========================================================================
% Change History
%      1998-11-13 (ToNo) Created
%      1998-12-18 (ToNo) Added the new files
%      1998-12-21 (ToNo) Added even more new files
%      1999-01-11 (ToNo) Updated before release
%      1999-01-18 (ToNo) Added getMaxVDSLlength
%      1999-03-25 (ToNo) Updated before release
%% ===========================================================================
