function f=getMinFreqaxis(maxf);
%% ===========================================================================
%getMinFreqaxis - Finds minimal set for frequency axis
%
% Parameter:    maxf	The max frequency to plot
% Returns:      f	Set of frequencies needed
%
% Example(s):
%
% Algorithmic details:
%
% Reference:
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1998 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Tomas Nordstrom (Tomas.B.Nordstrom@Telia.se)
%
% CVS:       $Id: getMinFreqaxis.m,v 1.3 1999/03/31 13:16:07 tono Exp $
%% ===========================================================================
% Change History
%      1998-12-17 (Dab)  Created
%      1998-12-21 (ToNo) Added comments
%      1999-01-07 (Dab)  +/- 1e3 on every frequency point
%      1999-02-26 (ToNo) Added frequency points for cable model breakpoints
%% ===========================================================================
global ex;

if nargin<1,
    maxf=ex.param.maxfrequency;
end

n=length(ex.tfplist);

f=[ex.param.minfrequency maxf];


for i=1:n,
    tmp=ex.tfplist(i).downstream;
    if strncmp(tmp,'calcPSD',7),
        start=findstr(tmp,'[');
        stop=findstr(tmp,']');
        tmp=str2num(tmp((start+1):(stop-1)));
        
        tmp=tmp(1:2:length(tmp));
        tmp2=tmp+1e3;
        tmp3=tmp-1e3;
        tmp2=union(tmp2,tmp3);
        tmp=union(tmp,tmp2);
        
        ind=find((tmp>0)&(tmp<maxf));
        tmp=tmp(ind);
        f=union(f,tmp);
        tmp2=tmp+1e3;
        tmp3=tmp-1e3;
        tmp2=union(tmp2,tmp3);
        tmp=union(tmp,tmp2);
    end;

    tmp=ex.tfplist(i).upstream;

    if strncmp(tmp,'calcPSD',7),
        start=findstr(tmp,'[');
        stop=findstr(tmp,']');
        tmp=str2num(tmp((start+1):(stop-1)));
        
        tmp=tmp(1:2:length(tmp));
        tmp2=tmp+1e3;
        tmp3=tmp-1e3;
        tmp2=union(tmp2,tmp3);
        tmp=union(tmp,tmp2);
        
        ind=find((tmp>0)&(tmp<maxf));
        tmp=tmp(ind);
        f=union(f,tmp);
        tmp2=tmp+1e3;
        tmp3=tmp-1e3;
        tmp2=union(tmp2,tmp3);
        f=union(f,tmp);   
    end;
end;

% Patch to fix ISDN PRA freq axis
tmp=[(150e3:150e3:30e6)];

% Patch to add cable model breakpoints
tmp=union(tmp,[0.5e6 5e6]);

% patch to add ADSL breakpoints
tmp=union(tmp,[25.875e3 138e3 1.104e6]);
f=union(f,tmp);

