function param = setupParam(vdslDuplex);
%% ===========================================================================
%setupParam - Sets up the experiment description structure for
% a certain FSAN duplex experiment.
%
% Parameter:    vdslDuplex	String describing vdsl duplex method under test
% Returns:      param		Structure describing the experiment parameters
%
% Example(s):
%   param = setupParam('VDSL-Zipper'); makes
%   all settings to test Zipper on the selected scenario
%
% Algorithmic details:
%   Fill in the ex.param structure according to default parameters and input
%   parameters.
%
% Reference:
%    FSAN duplex simulation memo, Telia 1998
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1998,99 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.B.Nordstrom@Telia.se)
%               : 
%
% CVS:       $Id: setupParam.m,v 1.3 1999/03/31 13:16:28 tono Exp $
%% ===========================================================================
% Change History
%      1998-10-19 (ToNo) Created
%      1998-11-13 (ToNo) Splitted setup into three parts param,tfplan,tt
%      1998-12-08 (DaB)  updated
%      1998-12-11 (DaB)  Added HAM band on/off (1/0)
%      1998-12-16 (DaB)  Added re_calc_bg_noise on/off (1/0)
%      1998-12-21 (ToNo) Moved efficiencyLoss into TF plans
%      1998-12-22 (ToNo) Updated comments
%      1999-01-05 (ToNo) Changed how modem under test was defined and
%                        added the possibility of precalculated noise models
%      1999-01-07 (ToNo) removed the duplex stuff (replaced by testADSL/testVDSL)
%      1999-01-18 (ToNo) Added DefaultMaxf as maxfrequency was set in evalExp.
%      1999-02-04 (DaB)  Added XTlevel for NEXT,FEXT,3CXT
%      1999-02-05 (DaB)  Added modemlist parameter for anaylsed modems in evalExperiment
%      1999-02-07 (ToNo) Modified list
%      1999-03-05 (ToNo) Renamed and modified hamband to use ITU-HAMBAND
%      1999-03-30 (DaB) Corrected thirdCXT value
%% ===========================================================================

% Check arguments
if nargin<1,
        vdslDuplex='TBD';
end

%% ===========================================================================
% System parameters

% General
param.backgroundNoise = -140;		% Backgound noise (dBm/Hz)
param.fastrecalc      = 1;		% 1 if fast calaculations should
                                        % be performed with a
                                        % minimalistic frequency axis.
                                        
% xDSL specifics
param.minfrequency    = 1;    		% Min frequency (Hz) to use
param.maxfrequency    = 30e6;    	% Max frequency (Hz) to use 
param.defaultMaxf     = 30e6;    	% Default Max frequency (Hz) to use 
param.granularity     = 1000;    	% Granularity (Hz) in the frequency domain 
                                        % to use (if not doing fastrecalc)
param.XTlevel.NEXT    =-50;             % Reference value at 1MHz
param.XTlevel.FEXT    =-45;		%         - -
param.XTlevel.thirdCXT=-75;            %         - -
                                        
                                        
% Technology specifics
param.SNRMax          = 60;		% Maximum SNR available (dB)
param.shannonGap      = 14.8; 	        % Shannon gap (dB)
param.efficiencyLoss  = 0; 		% Efficiency loss, due to things like cyclic
				        % prefix etc. // set in TF plans!
% Duplex specifics
param.modemlist=['VDSL'];                                        
param.testVDSL	      = 1;       	% Tells if VDSL is evaluated
param.testADSL	      = 0;       	% Tells if ADSL is evaluated
param.vdslDuplex      = vdslDuplex;     % VDSL Duplex method (used where
                                        % only VDSL is given

param.HAM             = 1;              % 1 if HAM band should be
                                        % compensated for
param.HambandName     = 'ITU-HAMBAND';  % Name of hamband to use

param.FSANNoiseModel  = 'Calculate'; 	% FSAN model to use if not Calculate
param.PBOmaxlen       = 1500;


% Derived parameters
param.f		      = ... 		% Frequency axis // set in evalExperiment!
    (param.minfrequency:param.granularity:param.maxfrequency);

